@@ -11,7 +11,7 @@ use strict;
 use warnings;
 
 package POE::Component::Client::MPD::Commands;
-our $VERSION = '1.093390';
+our $VERSION = '1.100430';
 # ABSTRACT: module handling basic mpd commands
 
 use Moose;
@@ -40,6 +40,16 @@ sub _do_version {
 
 
 
+sub _do_password {
+    my ($self, $msg) = @_;
+    my $pw = $msg->params->[0];
+    $msg->_set_commands( [ qq{password $pw} ] );
+    $msg->_set_cooking ( 'raw' );
+    $self->mpd->_send_to_mpd( $msg );
+}
+
+
+
 sub _do_kill {
     my ($self, $msg) = @_;
 
@@ -368,7 +378,7 @@ POE::Component::Client::MPD::Commands - module handling basic mpd commands
 
 =head1 VERSION
 
-version 1.093390
+version 1.100430
 
 =head1 DESCRIPTION
 
@@ -394,6 +404,11 @@ mpd returns B<protocol> version when connected. This protocol version can
 differ from the real mpd version. eg, mpd version 0.13.2 is "speaking"
 and thus advertising version 0.13.0.
 
+=head2 password( $password )
+
+Sends a connection password to mpd. Used internally on connect, but can
+be called whenever if you're feeling like it.
+
 =head2 kill( )
 
 Kill the mpd server, and request the pococm to be shutdown.
@@ -527,4 +542,5 @@ the same terms as the Perl 5 programming language system itself.
 =cut
 
 
-__END__
\ No newline at end of file
+__END__
+
